% FILE MOTORE_AS_PARAM.M (C) L. Zarri
% Parameters for the induction motor
% Last update: Maggio 2008

% Parameters of the induction machine

% Inductances (H)
Ls = 123.95e-3;         % Stator inductance
Lr = 123.95e-3;         % Rotor inductance
M = 118e-3;             % Magnetizing inductance
sigma =1-M*M/(Ls*Lr);   % Leakage coefficient

% Resistances (Ohm)
Rs=2.78;                % Stator
Rr=1.137;               % Rotor

% Pole pairs
p=2;

% Rated torque (Nm)
Cn=27;

% Rated voltage (phase to phase, rms)
Vn = 400;

% Rated current (A rms)
In=9.40;

% Rated frequency (Hz)
fn = 50;

% Rated mechanical speed in rpm e in rad/s
Nn = 1440;
Wn = Nn*2*pi/60;

% Rated slip
sn= 1 - Wn*p/(2*pi*fn);

% Rated rotor flux (Wb)
Frn = sqrt((2./3)*Rr*Cn/(p*sn*2*pi*fn));

% Rated current Id (peak Amps)
Idn = Frn/M;

% Rated current Iq (peak Amps)
Iqn = (2/3)*Cn*(Lr/M)/(p*Frn);

% Inertia of the motor(kg m^2)
Jm = 0.01330;

% INVERTER

% dc bus voltage (V)
Edc=700;

% Switching period (s)
Tc = 200e-6;

% LOAD

% Inertia of the load (kg m^2)
Jc = 3 * Jm; % Just an example.

% Friction coefficient (Nm s/rad)

b=1e-3;

% Load constant
Kc = Cn/Wn-b; % Just an example
            
% CONTROL SYSTEM

Rsn=Rs;
Rrn=Rr;
Lsn=Ls;
Lrn=Lr;
Mn=M;
sigman=1-Mn*Mn/(Lsn*Lrn);

% Max current (peak Amps)

Imax = 20;

% REGULATOR TUNING

J=Jc+Jm;            % Total Inertia;

s=tf('s');

% Controllo di corrente

tau_m=J/b;              % Mechanical constant
tau_er=Lr/Rr;           % Rotor time constant
tau_es=Ls/Rs;           % Stator time constant

Mot=1/(sigma*Ls*s+Rs);    % Transfer function without the back-emf
Del=1/(1+0.5*Tc*s);     % Transfer function

Gvi=Del*Mot; % TF Vref->I

% Current regulators (Phase Margin = 75, Wc=2620 rad/s) 
tau_i=sigman*Lsn/Rsn;
Ki_i=7664;
Kp_i=Ki_i*tau_i;

% Speed regulators

Wc=2620;
Giw=1.5*p*(M/Lr)*Frn*Del*(1/(J*s+b))*1/(1+s/Wc);

tau_w=0.31;
Ki_w=35.65;
